@@ -39,7 +39,7 @@ sub new_story {
     
     push @stories, {
         template_variables => {},
-        props => { dsl => Outthentic::DSL->new() },
+        props => { dsl => Outthentic::DSL->new() , response => [] },
     };
 
 }
@@ -47,7 +47,7 @@ sub new_story {
 sub end_of_story {
 
     if (debug_mod12()){
-        Test::More::ok(1,"end of story: ".(get_prop('check_list')));
+        Test::More::ok(1,'end of story: '.(get_prop('check_list')));
     }
     delete $stories[-1];
 
@@ -124,7 +124,9 @@ sub debug_mod12 {
 }
 
 sub set_response {
-    set_prop('response', shift());
+    my $cv = get_prop('response');
+    push @$cv, shift();
+    set_prop('response', $cv);
 }
 
 sub dsl {
